@@ -349,7 +349,7 @@ class RoborockClient:
     def _get_payload(
         self,
         method: RoborockCommand | str,
-        params: list | dict | None = None,
+        params: list | dict | int | None = None,
         secured=False,
     ):
         timestamp = math.floor(time.time())
@@ -381,7 +381,7 @@ class RoborockClient:
     async def _send_command(
         self,
         method: RoborockCommand | str,
-        params: list | dict | None = None,
+        params: list | dict | int | None = None,
     ):
         raise NotImplementedError
 
@@ -389,7 +389,7 @@ class RoborockClient:
     async def send_command(
         self,
         method: RoborockCommand | str,
-        params: list | dict | None = None,
+        params: list | dict | int | None = None,
         return_type: type[RT] | None = None,
     ) -> RT:
         cacheable_attribute_result = find_cacheable_attribute(method)
@@ -412,8 +412,11 @@ class RoborockClient:
             return return_type.from_dict(response)
         return response
 
-    async def get_status(self) -> Status | None:
-        return self._status_type.from_dict(await self.cache[CacheableAttribute.status].async_value())
+    async def get_status(self) -> Status:
+        data = self._status_type.from_dict(await self.cache[CacheableAttribute.status].async_value())
+        if data is None:
+            return self._status_type()
+        return data
 
     async def get_dnd_timer(self) -> DnDTimer | None:
         return DnDTimer.from_dict(await self.cache[CacheableAttribute.dnd_timer].async_value())
@@ -451,8 +454,11 @@ class RoborockClient:
             _LOGGER.warning("Clean record was of a new type, please submit an issue request: %s", record)
             return None
 
-    async def get_consumable(self) -> Consumable | None:
-        return Consumable.from_dict(await self.cache[CacheableAttribute.consumable].async_value())
+    async def get_consumable(self) -> Consumable:
+        data = Consumable.from_dict(await self.cache[CacheableAttribute.consumable].async_value())
+        if data is None:
+            return Consumable()
+        return data
 
     async def get_wash_towel_mode(self) -> WashTowelMode | None:
         return WashTowelMode.from_dict(await self.cache[CacheableAttribute.wash_towel_mode].async_value())
@@ -463,7 +469,7 @@ class RoborockClient:
     async def get_smart_wash_params(self) -> SmartWashParams | None:
         return SmartWashParams.from_dict(await self.cache[CacheableAttribute.smart_wash_params].async_value())
 
-    async def get_dock_summary(self, dock_type: RoborockDockTypeCode) -> DockSummary | None:
+    async def get_dock_summary(self, dock_type: RoborockDockTypeCode) -> DockSummary:
         """Gets the status summary from the dock with the methods available for a given dock.
 
         :param dock_type: RoborockDockTypeCode"""
@@ -525,11 +531,11 @@ class RoborockClient:
             ]
         return None
 
-    async def get_child_lock_status(self) -> ChildLockStatus | None:
+    async def get_child_lock_status(self) -> ChildLockStatus:
         """Gets current child lock status."""
         return ChildLockStatus.from_dict(await self.cache[CacheableAttribute.child_lock_status].async_value())
 
-    async def get_flow_led_status(self) -> FlowLedStatus | None:
+    async def get_flow_led_status(self) -> FlowLedStatus:
         """Gets current flow led status."""
         return FlowLedStatus.from_dict(await self.cache[CacheableAttribute.flow_led_status].async_value())
 
@@ -549,6 +555,12 @@ class RoborockClient:
     def add_listener(self, listener: Callable):
         self._listeners.append(listener)
 
+    async def get_from_cache(self, key: CacheableAttribute) -> AttributeCache | None:
+        val = self.cache.get(key)
+        if val is not None:
+            return await val.async_value()
+        return None
+
 
 class RoborockApiClient:
     def __init__(self, username: str, base_url=None) -> None:
