@@ -199,7 +199,7 @@ class RoborockMqttClient(RoborockClient, mqtt.Client):
     async def _send_command(
         self,
         method: RoborockCommand | str,
-        params: list | dict | None = None,
+        params: list | dict | int | None = None,
     ):
         request_id, timestamp, payload = super()._get_payload(method, params, True)
         request_protocol = RoborockMessageProtocol.RPC_REQUEST
